===================
django-lbattachment
===================

.. image:: https://secure.travis-ci.org/vicalloy/django-lbattachment.svg?branch=master
   :target: http://travis-ci.org/vicalloy/django-lbattachment

.. image:: https://coveralls.io/repos/github/vicalloy/django-lbattachment/badge.svg?branch=master
   :target: https://coveralls.io/github/vicalloy/django-lbattachment?branch=master

.. image:: https://img.shields.io/pypi/v/django-lbattachment.svg
   :target: https://pypi.python.org/pypi/django-lbattachment/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-lbattachment.svg
   :target: https://pypi.python.org/pypi/django-lbattachment/
   :alt: Number of PyPI downloads

A Django APP used to manager attachment.

``django-lbattachment`` supports `Django`_ 1.7.0 and later on Python 2.7,
3.2, 3.3 and 3.4.

.. _Django: http://www.djangoproject.com/


Getting Help
============

Documentation for django-lbattachment is available at https://django-lbattachment.readthedocs.org/


Contributing
============

Please file bugs and send pull requests to the `GitHub repository`_ and `issue
tracker`_.

.. _GitHub repository: https://github.com/vicalloy/django-lbattachment/
.. _issue tracker: https://github.com/vicalloy/django-lbattachment/issues
